@@ -1,4 +1,4 @@
-// -*- c-basic-offset: 2 -*-
+// -*- indent-tabs-mode: nil -*-
 /* This file is part of the KDE libraries
    Copyright (c) 2005 Klaus Niederkrueger <kniederk@math.uni-koeln.de>
 
@@ -69,6 +69,11 @@ KNumber::KNumber(quint32 num)
   _num = new _knuminteger(num);
 }
 
+KNumber::KNumber(qint64 num)
+{
+  _num = new _knuminteger(num);
+}
+
 KNumber::KNumber(quint64 num)
 {
   _num = new _knuminteger(num);
@@ -289,13 +294,14 @@ static void _round(QString &str, int precision)
 {
   int decimalSymbolPos = str.indexOf('.');
 
-  if (decimalSymbolPos == -1)
-    if (precision == 0)  return;
-    else if (precision > 0) // add dot if missing (and needed)
-      {
-	str.append('.');
-	decimalSymbolPos = str.length() - 1;
-      }
+  if (decimalSymbolPos == -1) {
+    if (precision == 0) {
+      return;
+    } else if (precision > 0) { // add dot if missing (and needed)
+      str.append('.');
+      decimalSymbolPos = str.length() - 1;
+    }
+  }
 
   // fill up with more than enough zeroes (in case fractional part too short)
   str.append(QString().fill('0', precision));
@@ -476,6 +482,16 @@ KNumber const KNumber::sqrt(void) const
   return tmp_num;
 }
 
+KNumber const KNumber::factorial(void) const
+{
+  KNumber tmp_num;
+  delete tmp_num._num;
+
+  tmp_num._num = _num->factorial();
+
+  return tmp_num;
+}
+
 KNumber const KNumber::integerPart(void) const
 {
   KNumber tmp_num;
@@ -673,25 +689,14 @@ KNumber::operator quint32(void) const
   return static_cast<unsigned long int>(*_num);
 }
 
+KNumber::operator qint64(void) const
+{
+  return static_cast<long long int>(*_num);
+}
+
 KNumber::operator quint64(void) const
 {
-#if SIZEOF_UNSIGNED_LONG == 8
-  return static_cast<unsigned long int>(*_num);
-#elif SIZEOF_UNSIGNED_LONG == 4
-  KNumber tmp_num1 = this->abs().integerPart();
-  quint64 tmp_num2 =  static_cast<quint32>(tmp_num1) +
-    (static_cast<quint64>(static_cast<quint32>(tmp_num1 >> KNumber("32"))) << 32) ;
-
-#ifdef __GNUC__
-#warning "the cast operator from KNumber to quint64 is probably buggy, when a sign is involved"
-#endif
-  if (*this > KNumber(0))
-    return tmp_num2;
-  else
-    return static_cast<quint64> (- static_cast<qint64>(tmp_num2));
-#else
-#error "SIZEOF_UNSIGNED_LONG is a unhandled case"
-#endif
+  return static_cast<unsigned long long int>(*_num);
 }
 
 KNumber::operator double(void) const
@@ -699,7 +704,7 @@ KNumber::operator double(void) const
   return static_cast<double>(*_num);
 }
 
-int const KNumber::compare(KNumber const & arg2) const
+int KNumber::compare(KNumber const & arg2) const
 {
   return _num->compare(*arg2._num);
 }
