@@ -1,12 +1,28 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdessh.cpp 325748 2004-07-04 13:19:05Z binner $
+ * $Id: kdessh.cpp 836029 2008-07-21 15:33:49Z kossebau $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
 
-#include <config.h>
+ /*
+ 
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License
+  as published by the Free Software Foundation; either version 2
+  of the License, or (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+ */
 
 #include <unistd.h>
 #include <string.h>
@@ -18,14 +34,14 @@
 #include <sys/resource.h>
 
 
-#include <kdebug.h>
-#include <kapplication.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <kmessagebox.h>
+#include <KDebug>
+#include <KApplication>
+#include <KStandardDirs>
+#include <KConfig>
+#include <KLocale>
+#include <KAboutData>
+#include <KCmdLineArgs>
+#include <KMessageBox>
 
 #include <kdesu/ssh.h>
 #include <kdesu/client.h>
@@ -33,29 +49,30 @@
 
 #include "sshdlg.h"
 
-static KCmdLineOptions options[] =
-{
-    { "+host", I18N_NOOP("Specifies the remote host"), 0 },
-    { "+command", I18N_NOOP("The command to run"), 0 },
-    { "u <user>", I18N_NOOP("Specifies the target uid"), 0 },
-    { "s <path>", I18N_NOOP("Specify remote stub location"), "kdesu_stub" },
-    { "n", I18N_NOOP("Do not keep password"), 0 },
-    { "q", I18N_NOOP("Stop the daemon (forgets all passwords)"), 0 },
-    { "t", I18N_NOOP("Enable terminal output (no password keeping)"), 0 },
-    KCmdLineLastOption
-};
+#include <QByteArray>
 
+using namespace KDESu;
 
 int main(int argc, char *argv[])
 {
-    KAboutData aboutData("kdessh", I18N_NOOP("KDE ssh"),
-	    VERSION, I18N_NOOP("Runs a program on a remote host"),
+    KAboutData aboutData("kdessh", 0, ki18n("KDE ssh"),
+	    KDE_VERSION_STRING, ki18n("Runs a program on a remote host"),
 	    KAboutData::License_Artistic,
-	    "Copyright (c) 2000 Geert Jansen");
-    aboutData.addAuthor("Geert Jansen", I18N_NOOP("Maintainer"),
+	    ki18n("Copyright (c) 2000 Geert Jansen"), KLocalizedString(),
+	    "http://utils.kde.org/projects/kdessh");
+    aboutData.addAuthor(ki18n("Geert Jansen"), ki18n("Maintainer"),
 	    "jansen@kde.org", "http://www.stack.nl/~geertj/");
 
     KCmdLineArgs::init(argc, argv, &aboutData);
+
+    KCmdLineOptions options;
+    options.add("+host", ki18n("Specifies the remote host"));
+    options.add("+command", ki18n("The command to run"));
+    options.add("u <user>", ki18n("Specifies the target uid"));
+    options.add("s <path>", ki18n("Specify remote stub location"), "kdesu_stub");
+    options.add("n", ki18n("Do not keep password"));
+    options.add("q", ki18n("Stop the daemon (forgets all passwords)"));
+    options.add("t", ki18n("Enable terminal output (no password keeping)"));
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication app;
@@ -67,51 +84,51 @@ int main(int argc, char *argv[])
 	KDEsuClient client;
 	if (client.ping() == -1)
 	{
-	    kdError(1511) << "Daemon not running -- nothing to stop\n";
+	    kError(1511) << "Daemon not running -- nothing to stop\n";
 	    exit(1);
 	}
 	if (client.stopServer() != -1)
 	{
-	    kdDebug(1511) << "Daemon stopped\n";
+	    kDebug(1511) << "Daemon stopped\n";
 	    exit(0);
 	}
-	kdError(1511) << "Could not stop daemon\n";
+	kError(1511) << "Could not stop daemon\n";
 	exit(1);
     }
 
     if (args->count() < 2)
-	KCmdLineArgs::usage(i18n("No command or host specified."));
+	KCmdLineArgs::usageError(i18n("No command or host specified."));
 
     // Check if ssh is available
     if (KStandardDirs::findExe(QString::fromLatin1("ssh")).isEmpty())
     {
-	kdError(1511) << "ssh not found\n";
+	kError(1511) << "ssh not found\n";
 	exit(1);
     }
 
     // Get remote userid
-    QCString user = args->getOption("u");
+    QByteArray user = args->getOption("u").toLocal8Bit();
     if (user.isNull())
     {
 	struct passwd *pw = getpwuid(getuid());
 	if (pw == 0L)
 	{
-	    kdError(1511) << "You don't exist!\n";
+	    kError(1511) << "You don't exist!\n";
 	    exit(1);
 	}
 	user = pw->pw_name;
     }
 
     // Remote stub location
-    QCString stub = args->getOption("s");
+    QByteArray stub = args->getOption("s").toLocal8Bit();
 
     // Get remote host, command
-    QCString host = args->arg(0);
-    QCString command = args->arg(1);
+    QByteArray host = args->arg(0).toLocal8Bit();
+    QByteArray command = args->arg(1).toLocal8Bit();
     for (int i=2; i<args->count(); i++)
     {
-	command += " ";
-	command += args->arg(i);
+	command += ' ';
+	command += args->arg(i).toLocal8Bit();
     }
 
     // Check for daemon and start if necessary
@@ -119,12 +136,12 @@ int main(int argc, char *argv[])
     KDEsuClient client;
     if (!client.isServerSGID())
     {
-	kdWarning(1511) << "Daemon not safe (not sgid), not using it.\n";
+	kWarning(1511) << "Daemon not safe (not sgid), not using it.\n";
 	have_daemon = false;
     }
     else if ((client.ping() == -1) && (client.startServer() == -1))
     {
-	kdWarning(1511) << "Could not start daemon, reduced functionality.\n";
+	kWarning(1511) << "Could not start daemon, reduced functionality.\n";
 	have_daemon = false;
     }
 
@@ -144,29 +161,28 @@ int main(int argc, char *argv[])
     rlim.rlim_cur = rlim.rlim_max = 0;
     if (setrlimit(RLIMIT_CORE, &rlim))
     {
-	kdError(1511) << "rlimit(): " << perror << "\n";
+	kError(1511) << "rlimit(): " << perror << "\n";
 	exit(1);
     }
 
 
     // Read configuration
-    KConfig *config = KGlobal::config();
-    config->setGroup(QString::fromLatin1("Passwords"));
-    int timeout = config->readNumEntry(QString::fromLatin1("Timeout"), defTimeout);
+    KConfigGroup config = KGlobal::config()->group("Passwords");
+    int timeout = config.readEntry(QString::fromLatin1("Timeout"), defTimeout);
 
     SshProcess proc(host, user);
     proc.setStub(stub);
     int needpw = proc.checkNeedPassword();
     if (needpw < 0)
     {
-	QString msg = i18n("Ssh returned with an error!\n"
+	QString msg = i18n("Ssh returned with an error.\n"
 		"The error message is:\n\n");
 	msg += proc.error();
 	KMessageBox::error(0L, msg);
 	exit(1);
     }
 
-    QCString password;
+    QByteArray password;
     if (needpw != 0)
     {
 	KDEsshDialog *dlg = new KDEsshDialog(host, user, stub,
