@@ -22,19 +22,19 @@
 #ifndef __KDF_H__
 #define __KDF_H__
 
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kmenubar.h>
 
 #include "kdfwidget.h"
 
 /***************************************************************/
-class KDFTopLevel : public KMainWindow
+class KDFTopLevel : public KXmlGuiWindow
 {
  Q_OBJECT
 
   public:
-    KDFTopLevel(QWidget *parent=0, const char *name=0);
-    ~KDFTopLevel() { };
+    KDFTopLevel(QWidget *parent=0);
+    ~KDFTopLevel() { }
 
   protected slots:
     virtual bool queryExit( void );
