@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -24,22 +24,18 @@
 #ifndef _KWIKDISK_H_
 #define _KWIKDISK_H_
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "disklist.h"
 #include "stdoption.h"
 #include "optiondialog.h"
 
-#include <kmainwindow.h>
-#include <ksystemtray.h>
+#include <kxmlguiwindow.h>
+#include <ksystemtrayicon.h>
 
 /**
 * @short Application Main Window (however in Tray)
 * @version 0.2
 */
-class KwikDisk : public KSystemTray
+class KwikDisk : public KSystemTrayIcon
 {
    Q_OBJECT
    public:
@@ -53,10 +49,8 @@ class KwikDisk : public KSystemTray
       void changeSettings();
       void startKDF();
       void invokeHelp();
-      void aboutToHide();
-
+      void slotActivated(QSystemTrayIcon::ActivationReason reason);
    private:
-      void mousePressEvent(QMouseEvent *);
       void timerEvent(QTimerEvent *);
       void enterEvent(QEvent *);
       void leaveEvent(QEvent *);
