@@ -1,5 +1,5 @@
 /*
- * (c) 2001 Stefan Schimanski <schimmi@kde.org>
+ * Copyright 2001 Stefan Schimanski <schimmi@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,20 +26,20 @@
 static const char description[] =
         I18N_NOOP("KDE Timer");
 
-static const char version[] = "v0.1";
+static const char version[] = "v0.2";
 
 int main( int argc, char **argv )
 {
-    KAboutData aboutData( "ktimer", I18N_NOOP("KTimer"),
-                          version, description, KAboutData::License_GPL,
-                          "(c) 2001, Stefan Schimanski");
-    aboutData.addAuthor("Stefan Schimanski",0, "schimmi@kde.org");
+    KAboutData aboutData( "ktimer", 0, ki18n("KTimer"),
+                          version, ki18n(description), KAboutData::License_GPL,
+                          ki18n("(c) 2001, Stefan Schimanski"), KLocalizedString(),
+                          "http://utils.kde.org/projects/ktimer");
+    aboutData.addAuthor(ki18n("Stefan Schimanski"),KLocalizedString(), "schimmi@kde.org");
     KCmdLineArgs::init( argc, argv, &aboutData );
 
     KApplication app;
 
     KTimerPref *timer = new KTimerPref;
-    app.setMainWidget( timer );
     app.setTopWidget( timer );
 
     return app.exec();
